Sign inSign up

defnotgustavom/speedtest-go

By defnotgustavom

•Updated about 3 years ago

Image size: ~2.39MiB. CLI network speed test, powered by speedtest.net. USER: nobody.

Image
0

3.8K

defnotgustavom/speedtest-go repository overview

  • Running:

docker run -it --rm --log-driver none --read-only defnotgustavom/speedtest-go


⁠Usage

 speedtest-go [<flags>]
  • Flags:

    --help                   Show context-sensitive help (also try --help-long and --help-man).
    
     -l, --list                   Show available speedtest.net servers.
    
     -s, --server=SERVER ...      Select server id to speedtest.
    
    --custom-url=CUSTOM-URL  Specify the url of the server instead of getting a list from speedtest.net.
    
    --saving-mode            Test with few resources, though low accuracy (especially > 30Mbps).
    
    --json                   Output results in json format.
    
    --location=LOCATION      Change the location with a precise coordinate.
    
    --city=CITY              Change the location with a predefined city label.
    
    --city-list              List all predefined city labels.
    
    --proxy=PROXY            Set a proxy(http[s] or socks) for the speedtest.
    
                             eg: --proxy=socks://10.20.0.101:7890
    
                             eg: --proxy=http://10.20.0.101:7890
    
    --source=SOURCE          Bind a source interface for the speedtest.
    
                             eg: --source=10.20.0.101
    
     -m  --multi                  Enable multi-server mode.
    
     -t  --thread=THREAD          Set the number of concurrent connections.
    
    --search=SEARCH          Fuzzy search servers by a keyword.
    
    --no-download            Disable download test.
    
    --no-upload              Disable upload test.
    
    --force-http-ping        Force ping using http.
    
     -d  --debug                  Enable debug mode.
    
    --version                Show application version.
    
  • Test Internet Speed

Simply use speedtest command. The closest server is selected by default. Use the -m flag to enable multi-measurement mode (recommended)

 $ speedtest
 Testing From IP: 124.27.199.165 (Fujitsu) [34.9769, 138.3831]
 Target Server: [6691]     9.03km Shizuoka (Japan) by sudosan
 Latency: 24.15396ms
 Jitter: 777.465µs
 Min: 22.8926ms
 Max: 25.5387ms
 Download Test: ................
 Upload Test: ................

 Download: 73.30 Mbit/s
 Upload: 35.26 Mbit/s
 Test to Other Servers
 If you want to select other servers to test, you can see the available server list.

  $ speedtest --list
  Testing From IP: 124.27.199.165 (Fujitsu) [34.9769, 138.3831]
  [6691]     9.03km   32.3365ms  Shizuoka (Japan) by sudosan
  [6087]   120.55km   51.7453ms  Fussa-shi (Japan) by Allied Telesis Capital Corporation
  [6508]   125.44km   54.6683ms  Yokohama (Japan) by at2wn
 [6424]   148.23km   61.4724ms  Tokyo (Japan) by Cordeos Corp.
 ...
 and select them by id.

$ speedtest --server 6691 --server 6087

Testing From IP: 124.27.199.165 (Fujitsu) [34.9769, 138.3831]

Target Server: [6691] 9.03km Shizuoka (Japan) by sudosan

Latency: 21.424ms

Jitter: 1.644ms

Min: 19.142ms

Max: 23.926ms

Download Test: ................

Upload Test: ........

Target Server: [6087] 120.55km Fussa-shi (Japan) by Allied Telesis Capital Corporation

Latency: 38.694699ms

Jitter: 2.724ms

Min: 36.443ms

Max: 39.953ms

Download Test: ................

Upload Test: ................

[6691] Download: 65.82 Mbit/s, Upload: 27.00 Mbit/s

[6087] Download: 72.24 Mbit/s, Upload: 29.56 Mbit/s

Download Avg: 69.03 Mbit/s

Upload Avg: 28.28 Mbit/s

  • Test with a virtual location

With --city or --location option, the closest servers of the location will be picked. You can measure the speed between your location and the target location.

$ speedtest --city-list

Available city labels (case insensitive):

CC CityLabel Location

(za) capetown [-33.9391993, 18.4316716]

(pl) warsaw [52.2396659, 21.0129345]

(sg) yishun [1.4230218, 103.8404728]

...

$ speedtest --city=capetown

$ speedtest --location=60,-110

  • Memory Saving Mode

With --saving-mode option, it can be executed even in an insufficient memory environment like IoT devices. The memory usage can be reduced to 1/10, about 10MB of memory is used.

However, please be careful that the accuracy is particularly low, especially in an environment of 30 Mbps or higher. To get more accurate results, run multiple times and average.

For more details, please see saving mode experimental result.

This feature has been deprecated > v1.4.0, because speedtest-go can always run with less than 10MByte of memory now. Even so, --saving-mode is still a good way to save computer performance.

Tag summary

Content type

Image

Digest

sha256:ac4a11823…

Size

2.4 MB

Last updated

about 3 years ago

docker pull defnotgustavom/speedtest-go